@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-19 11:33:16
-@LastEditTime: 2021-08-31 19:13:28
+@LastEditTime: 2021-09-01 17:17:43
 @LastEditors: HuangJianYi
 :description: 用户处理
 """
@@ -726,3 +726,67 @@ class GetPropGiveHandler(SevenBaseHandler):
             self.logging_link_error("GetPropGiveHandler:" + str(ex))
             return self.reponse_json_error("Error", "系统繁忙,请稍后再试")
         return self.reponse_json_success({"prop_type": prop_give.prop_type, "num": 1})
+
+
+class PropGiveListHandler(SevenBaseHandler):
+    """
+    :description: 道具赠送记录列表
+    """
+    @filter_check_params("act_id")
+    def get_async(self):
+        """
+        :description: 道具赠送记录列表
+        :param page_index：页索引
+        :param page_size：页大小
+        :param act_id：活动id
+        :param user_open_id：赠送人open_id
+        :param nick_name：赠送人淘宝名
+        :param draw_open_id：领取人open_id
+        :param draw_nick_name：领取人淘宝名
+        :param start_date：开始时间
+        :param end_date：结束时间
+        :param give_status：赠送状态(0未领取1已领取2已失效)
+        :return list
+        :last_editors: HuangJianYi
+        """
+        page_index = int(self.get_param("page_index", 0))
+        page_size = int(self.get_param("page_size", 20))
+        act_id = int(self.get_param("act_id", 0))
+        user_nick = self.get_param("nick_name")
+        user_open_id = self.get_param("user_open_id")
+        draw_user_nick = self.get_param("draw_nick_name")
+        draw_open_id = self.get_param("draw_open_id")
+        start_date = self.get_param("start_date")
+        end_date = self.get_param("end_date")
+        give_status = int(self.get_param("give_status", -1))
+
+        condition = "act_id=%s"
+        params = [act_id]
+
+        if give_status >= 0:
+            condition += " AND give_status=%s"
+            params.append(give_status)
+        if user_open_id:
+            condition += " AND open_id=%s"
+            params.append(user_open_id)
+        if user_nick:
+            condition += " AND user_nick=%s"
+            params.append(user_nick)
+        if draw_open_id:
+            condition += " AND draw_open_id=%s"
+            params.append(draw_open_id)
+        if draw_user_nick:
+            condition += " AND draw_user_nick=%s"
+            params.append(draw_user_nick)
+        if start_date:
+            condition += " AND create_date>=%s"
+            params.append(start_date)
+        if end_date:
+            condition += " AND create_date<=%s"
+            params.append(end_date)
+
+        page_list, total = PropGiveModel(context=self).get_dict_page_list("*", page_index, page_size, condition, order_by="id desc", params=params)
+
+        page_info = PageInfo(page_index, page_size, total, page_list)
+
+        return self.reponse_json_success(page_info)
\ No newline at end of file
