@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2021-08-31 17:12:59
+@LastEditTime: 2021-09-01 15:56:37
 @LastEditors: HuangJianYi
 :Description: 潮玩盲盒基础路由
 """
@@ -97,6 +97,9 @@ def seven_cloudapp_ppmt_route():
         (r"/server/lottery_value_log_list", user_s.LotteryValueLogHandler),
         # 2.1优化
         (r"/server/checking_price_gear", machine_s.CheckingPriceGearHandler),  #验证价格档位
+        # 2.2
+        (r"/server/give_prop_list", user_s.PropGiveListHandler),
+        (r"/server/shop_power_config", power_s.ShopPowerConfigHandler),
 
         # 客户端接口
         (r"/client/login", user.LoginHandler),
@@ -135,10 +138,13 @@ def seven_cloudapp_ppmt_route():
         (r"/client/exchange_list", exchange.ExchangeListHandler),
         (r"/client/user_detail", user.GetUserDetailHandler),
         (r"/client/integral_list", user.GetIntegralListHandler),
-        (r"/client/give_prop", user.GivePropHandler),
-        (r"/client/get_prop_give", user.GetPropGiveHandler),
         (r"/client/lottery_all", lottery.LotteryAllHandler),
         (r"/client/use_reset_card", lottery.UseResetCardHandler),
         (r"/client/use_perspective_card", lottery.UsePerspectiveCardHandler),
         (r"/client/active_new_user", task.ActiveNewUserHandler),
+        #2.2
+        (r"/client/shop_power_config", power.ShopPowerConfigHandler),
+        (r"/client/give_prop", user.GivePropHandler),
+        (r"/client/get_prop_give", user.GetPropGiveHandler),
+        (r"/client/give_prop_list", user.PropGiveListHandler),
     ]
\ No newline at end of file
